%
% ``icat'' LaTeX class.
% - borrows *heavily* from Daniel Kartch's and Stephen Spencer's 'siggraph' class. 
% - 2005/06/30 converted for ICAT 2005 format by Greg Welch (welch@cs.unc.edu)
% - also uses pieces of 'apalike.sty' and 'authordate1-4.cls'
% - modifications include adjustment of citation format to more closely
%   align with new (for SIGGRAPH 2002 conference and beyond) reference
%   and citation formatting requirements.
% - version 0.1 2001/06/01 Stephen Spencer (spencer@acm.org)
% - version 0.2 2001/10/15 Stephen Spencer
%   - the "\onlineid" variable works with the "review" mode, placing a
%     banner across the top of each page "Online Submission ID 'onlineid'
% - version 0.3 2002/01/11 Stephen Spencer
%   - disabled the cover page option.
% - version 0.4 2002/01/23 Stephen Spencer
%   - based on suggestions from James O'Brien, the following changes:
%     - correction if '\ifcamera' and '\ifcameraelse' commands
%     - page numbering in both review and preprint modes
%     have been made.
% - version 0.5 2005/01/22 Stephen Spencer
%   - removed the category markers
%
% ------------ identification --------------
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{icat}[2005/06/23 ICAT]

% ------------ initial code --------------

\newif\ificat@camera
\newif\ificat@preprint
\newif\ificat@review
\newif\ificat@doublespaced

\newcommand{\icat@columnmode}{}
\newcommand{\icat@pointsize}{}

% ------------ declaration of options --------------

% 'cameraready' option.

\DeclareOption{cameraready}{%
    \icat@cameratrue%
    \icat@preprintfalse%
    \icat@reviewfalse%
    \renewcommand{\icat@columnmode}{twocolumn}%
    \icat@doublespacedfalse%
    \renewcommand{\icat@pointsize}{10pt}}

% 'review' option.

\DeclareOption{review}{%
    \icat@camerafalse%
    \icat@preprintfalse%
    \icat@reviewtrue%
    \renewcommand{\icat@columnmode}{twocolumn}%
    \icat@doublespacedfalse%
    \renewcommand{\icat@pointsize}{10pt}}

% 'widereview' option.

\DeclareOption{widereview}{%
    \icat@camerafalse%
    \icat@preprintfalse%
    \icat@reviewtrue%
    \renewcommand{\icat@columnmode}{onecolumn}%
    \icat@doublespacedtrue%
    \renewcommand{\icat@pointsize}{12pt}}

% 'preprint' option.

\DeclareOption{preprint}{%
    \icat@camerafalse%
    \icat@preprinttrue%
    \icat@reviewfalse%
    \renewcommand{\icat@columnmode}{twocolumn}%
    \icat@doublespacedfalse%
    \renewcommand{\icat@pointsize}{10pt}}

% Assume, for the moment, that we're preparing a 'cameraready' version.

\ExecuteOptions{cameraready}

% Here's a warning command for use just below.

\newcommand{\icat@optwarning}[1]{%
    \ificat@camera
        \ClassWarningNoLine{icat}%
            {#1 option used in camera-ready mode.\MessageBreak
             This violates submission specifications}
    \fi
}

% The 'onecolumn' option doesn't work in 'cameraready' mode.

\DeclareOption{onecolumn}{%
    \icat@optwarning{onecolumn}
    \renewcommand{\icat@columnmode}{onecolumn}}

% The 'twocolumn' option works in 'cameraready' mode.

\DeclareOption{twocolumn}{%
    \renewcommand{\icat@columnmode}{twocolumn}}

% Only the '9pt' and '10pt' sizes work in 'cameraready' mode.

\DeclareOption{9pt}{%
    \renewcommand{\icat@pointsize}{9pt}}
\DeclareOption{10pt}{%
    \icat@optwarning{10pt}
    \renewcommand{\icat@pointsize}{10pt}}
\DeclareOption{11pt}{%
    \icat@optwarning{11pt}
    \renewcommand{\icat@pointsize}{11pt}}
\DeclareOption{12pt}{%
    \icat@optwarning{12pt}
    \renewcommand{\icat@pointsize}{12pt}}

% The 'singlespace' option works in 'cameraready' mode.

\DeclareOption{singlespace}{%
    \icat@doublespacedfalse}

% The 'doublespace' option does not work in 'cameraready' mode.

\DeclareOption{doublespace}{%
    \icat@optwarning{doublespace}
    \icat@doublespacedtrue}

% No 'titlepage' option in 'cameraready' mode.

\DeclareOption{titlepage}{%
    \OptionNotUsed%
    \ClassWarningNoLine{icat}{titlepage option not allowed}}

% No 'landscape' mode in 'cameraready' mode, either.

\DeclareOption{landscape}{%
    \OptionNotUsed%
    \ClassWarningNoLine{icat}{landscape option not allowed}}

% Pass everything else to the 'artlcle' class, upon which this is based.

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\PassOptionsToClass{\icat@columnmode}{article}
\ifdim\icat@pointsize>9pt
    \PassOptionsToClass{\icat@pointsize}{article}
\fi

% ------------ package loading --------------

\LoadClass{article}

% ------------ main code --------------

\newcommand{\icat@onlineid}{}
\newcommand{\onlineid}[1]{\renewcommand{\icat@onlineid}{#1}}

\newcommand{\icat@preprinttext}{To appear in the ICAT conference proceedings}
\newcommand{\preprinttext}[1]{\renewcommand{\icat@preprinttext}{#1}}

\newcommand{\icat@reviewtext}{Online Submission ID: \icat@onlineid}
\newcommand{\reviewtext}[1]{\renewcommand{\icat@reviewtext}{#1}}

\newcommand{\ifcamera}[1]{\ificat@camera #1 \fi}
\newcommand{\ifreview}[1]{\ificat@review #1 \fi}
\newcommand{\ifcameraelse}[2]{\ificat@camera #1 \else #2 \fi}
\newcommand{\ifreviewelse}[2]{\ificat@review #1 \else #2 \fi}

\renewcommand{\ps@plain}%
    {%
    \renewcommand{\@oddhead}{}%
    \renewcommand{\@oddfoot}{}%

    \ificat@preprint%
      \renewcommand{\@oddhead}{\hfil\textit{\large\icat@preprinttext}\hfil}%
      \renewcommand{\@oddfoot}{\hfil\textrm{\thepage}\hfil}%
    \fi%

    \ificat@review%
      \renewcommand{\@oddhead}{\hfil\textit{\large\icat@reviewtext}\hfil}%
      \renewcommand{\@oddfoot}{\hfil\textrm{\thepage}\hfil}%
    \fi%

    \renewcommand{\@evenhead}{\@oddhead}%
    \renewcommand{\@evenfoot}{\@oddfoot}%
    }

\renewcommand{\ps@empty}%
    {%
    \renewcommand{\@oddhead}{}%
    \renewcommand{\@oddfoot}{}%

    \ificat@preprint%
      \renewcommand{\@oddhead}{\hfil\textit{\large\icat@preprinttext}\hfil}%
      \renewcommand{\@oddfoot}{\hfil\textrm{\thepage}\hfil}%
    \fi%

    \ificat@review%
      \renewcommand{\@oddhead}{\hfil\textit{\large\icat@reviewtext}\hfil}%
      \renewcommand{\@oddfoot}{\hfil\textrm{\thepage}\hfil}%
    \fi%

    \renewcommand{\@evenhead}{\@oddhead}%
    \renewcommand{\@evenfoot}{\@oddfoot}%
    }

% no page numbers - they are added in production

\pagestyle{plain}

\newcommand{\icat@setninepoint}{
    \renewcommand\normalsize{%
        \@setfontsize\normalsize\@ixpt\@xpt
        \abovedisplayskip 9\p@ \@plus2\p@ \@minus4\p@
        \abovedisplayshortskip \z@ \@plus3\p@
        \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
        \belowdisplayskip \abovedisplayskip
        \let\@listi\@listI}
    \renewcommand\small{%
        \@setfontsize\small\@viipt\@ixpt
        \abovedisplayskip 8.5\p@ \@plus3\p@ \@minus4\p@
        \abovedisplayshortskip \z@ \@plus2\p@
        \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
        \def\@listi{\leftmargin\leftmargini
                    \topsep 4\p@ \@plus2\p@ \@minus2\p@
                    \parsep 2\p@ \@plus\p@ \@minus\p@
                    \itemsep \parsep}%
        \belowdisplayskip \abovedisplayskip}
    \renewcommand\footnotesize{%
        \@setfontsize\footnotesize\@viiipt{9.5}%
        \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
        \abovedisplayshortskip \z@ \@plus\p@
        \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
        \def\@listi{\leftmargin\leftmargini
                    \topsep 3\p@ \@plus\p@ \@minus\p@
                    \parsep 2\p@ \@plus\p@ \@minus\p@
                    \itemsep \parsep}%
        \belowdisplayskip \abovedisplayskip}
    \renewcommand\scriptsize{\@setfontsize\scriptsize\@viipt\@viiipt}
    \renewcommand\tiny{\@setfontsize\tiny\@vpt\@vipt}
    \renewcommand\large{\@setfontsize\large\@xpt\@xiipt}
    \renewcommand\Large{\@setfontsize\Large\@xiipt{14}}
    \renewcommand\LARGE{\@setfontsize\LARGE\@xivpt{18}}
    \renewcommand\huge{\@setfontsize\huge\@xviipt{22}}
    \renewcommand\Huge{\@setfontsize\Huge\@xxpt{25}}
    \selectfont
}
\newcommand{\icat@settenpoint}{
    \renewcommand\normalsize{%
        \@setfontsize\normalsize\@ixpt\@xpt
        \abovedisplayskip 10\p@ \@plus2\p@ \@minus4\p@
        \abovedisplayshortskip \z@ \@plus3\p@
        \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
        \belowdisplayskip \abovedisplayskip
        \let\@listi\@listI}
    \renewcommand\small{%
        \@setfontsize\small\@viipt\@ixpt
        \abovedisplayskip 8.5\p@ \@plus3\p@ \@minus4\p@
        \abovedisplayshortskip \z@ \@plus2\p@
        \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
        \def\@listi{\leftmargin\leftmargini
                    \topsep 4\p@ \@plus2\p@ \@minus2\p@
                    \parsep 2\p@ \@plus\p@ \@minus\p@
                    \itemsep \parsep}%
        \belowdisplayskip \abovedisplayskip}
    \renewcommand\footnotesize{%
        \@setfontsize\footnotesize\@viiipt{9.5}%
        \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
        \abovedisplayshortskip \z@ \@plus\p@
        \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
        \def\@listi{\leftmargin\leftmargini
                    \topsep 3\p@ \@plus\p@ \@minus\p@
                    \parsep 2\p@ \@plus\p@ \@minus\p@
                    \itemsep \parsep}%
        \belowdisplayskip \abovedisplayskip}
    \renewcommand\scriptsize{\@setfontsize\scriptsize\@viipt\@viiipt}
    \renewcommand\tiny{\@setfontsize\tiny\@vpt\@vipt}
    \renewcommand\large{\@setfontsize\large\@xpt\@xiipt}
    \renewcommand\Large{\@setfontsize\Large\@xiipt{14}}
    \renewcommand\LARGE{\@setfontsize\LARGE\@xivpt{18}}
    \renewcommand\huge{\@setfontsize\huge\@xviipt{20}}
    \renewcommand\Huge{\@setfontsize\Huge\@xxpt{24}}
    \selectfont
}
\ifdim\icat@pointsize=9pt
    \icat@setninepoint
\fi
\ifdim\icat@pointsize=10pt
    \icat@settenpoint
\fi

\newcommand{\icat@sectionfont}{}
\newcommand{\sectionfont}[1]{\renewcommand{\icat@sectionfont}{#1}}
\renewcommand\section{\@startsection {section}{1}{\z@}%
                {-3.5ex \@plus -1ex \@minus -.2ex}%
                {2.3ex \@plus.2ex}%
                {\reset@font\Large\bfseries\icat@sectionfont}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                {-3.25ex\@plus -1ex \@minus -.2ex}%
                {1.5ex \@plus .2ex}%
                {\reset@font\large\bfseries\icat@sectionfont}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                {-3.25ex\@plus -1ex \@minus -.2ex}%
                {1.5ex \@plus .2ex}%
                {\reset@font\normalsize\bfseries\icat@sectionfont}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                {3.25ex \@plus1ex \@minus.2ex}%
                {-1em}%
                {\reset@font\normalsize\bfseries\icat@sectionfont}}

\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
                {3.25ex \@plus1ex \@minus .2ex}%
                {-1em}%
                {\reset@font\normalsize\bfseries\icat@sectionfont}}
                
                
% the following is only needed to add a . after the section name
% otherwise it is a copy from latex.ltx

\def\@sect#1#2#3#4#5#6[#7]#8{\ifnum #2>\c@secnumdepth
     \def\@svsec{}\else 
     \refstepcounter{#1}\edef\@svsec{\csname the#1\endcsname.\hskip .3em }\fi
     \@tempskipa #5\relax
      \ifdim \@tempskipa>\z@ 
        \begingroup #6\relax
          \@hangfrom{\hskip #3\relax\@svsec}{\interlinepenalty \@M #8\par}
        \endgroup
       \csname #1mark\endcsname{#7}\addcontentsline
         {toc}{#1}{\ifnum #2>\c@secnumdepth \else
                      \protect\numberline{\csname the#1\endcsname}\fi
                    #7}\else
       \def\@svsechd{#6\hskip #3\@svsec #8.\hskip .1em\csname #1mark\endcsname
                      {#7}\addcontentsline
                           {toc}{#1}{\ifnum #2>\c@secnumdepth \else
                             \protect\numberline{\csname the#1\endcsname}\fi
                       #7}}\fi
     \@xsect{#5}}


\newcommand{\icat@empty}{}

\newcommand{\icat@affiliation}{}
\newcommand{\affiliation}[1]{\renewcommand{\icat@affiliation}{#1}}

\newcommand{\icat@format}{}
\newcommand{\format}[1]{\renewcommand{\icat@format}{#1}}
\newcommand{\icatformat}[1]{\format{#1}}

\newcommand{\icat@teaser}{}
\newcommand{\teaser}[1]{\renewcommand{\icat@teaser}{#1}}

\newlength{\titlespace}
\setlength{\titlespace}{0.25in}

\newlength{\teaserspace}
\setlength{\teaserspace}{0.25in}

\ificat@review
    \renewcommand{\@maketitle}{%
        \begin{center}%
            \renewcommand{\thanks}[1]{}
            {\huge\bfseries\icat@sectionfont \@title \par}%
            \vspace{1\baselineskip}%
            \vspace{\titlespace}%
            \ifx\icat@teaser\icat@empty \else%
                \begingroup%
                    \def\@captype{figure}%
                    \icat@teaser%
                \endgroup\par%
                \vspace{\teaserspace}%
            \fi%
        \end{center} \par%
    }
\else
    \renewcommand{\@maketitle}{%
        \begin{center}%
            {\huge\bfseries\icat@sectionfont \@title \par}%
            \vspace{1\baselineskip}%
            \Large
            \begin{tabular}[t]{c}%
                \bfseries \@author
            \end{tabular}\par%
            \ifx\icat@affiliation\icat@empty \else%
            	\large
                \vspace{0.1\baselineskip}%
                \icat@affiliation\par%
            \fi%
            \vspace{\titlespace}%
            \ifx\icat@teaser\icat@empty \else%
                \begingroup%
                    \def\@captype{figure}%
                    \icat@teaser%
                \endgroup\par%
                \vspace{\teaserspace}%
            \fi%
        \end{center} \par%
    }
\fi

\let\icat@origmaketitle\maketitle
\let\icat@origand\and
\renewcommand{\maketitle}{%
    \let\icat@title\@title%
    \let\icat@author\@author%
    \icat@origmaketitle%
    \thispagestyle{empty}%
    \ificat@doublespaced%
        \renewcommand{\baselinestretch}{1.66}\selectfont%
    \fi
}

\newtoks\icat@abs
\ificat@review
    \long\def\icat@add#1{\global\icat@abs\expandafter{\the\icat@abs#1}}
    \long\def\icat@collect{%
        \global\icat@abs{}%
        \let\abstract\icat@@collect
        \abstract
    }
    \long\def\icat@@collect#1\end#2{%
        \def\@tempa{#2}%
        \ifx\@tempa\@currenvir
            \icat@add{#1}%
            \edef\abstract{\noexpand\end{\@tempa}}%
        \else
            \icat@add{#1\end{#2}}%
        \fi
        \abstract
    }
    \newcommand{\icat@modify}{%
        \let\icat@origabs\abstract%
        \let\icat@origendabs\endabstract%
        \renewenvironment{abstract}%
            {\icat@collect}%
            {\begingroup
                \let\abstract\icat@origabs
                \let\endabstract\icat@origendabs
                \begin{abstract} \the\icat@abs \end{abstract}
            \endgroup}%
    }
    \AtBeginDocument{\icat@modify}
\fi
\newcommand{\keywordlist}{%
    \vspace{0.8\baselineskip}%
    \par\noindent \textbf{Keywords: } \icat@keywords%
}
\newenvironment{CRcatlist}{%
    \vspace{0.5\baselineskip}%
    \par\noindent \textbf{CR Categories: }%
}{}

\newcommand{\CRcat}[4]{%
    #1 [#2]%
    \ifx#3\icat@empty \else : #3\fi%
    \ifx#4\icat@empty \else ---#4\fi%
}

% leave a 1.0 inch space at the bottom of the left column
% on the first page for the copyright block.

\newlength{\icat@copyrightlength}
\setlength{\icat@copyrightlength}{1.0in}

\newcommand{\copyrightspace}{%
    \renewcommand{\thefootnote}{}%
    \footnotetext[0]{\rule[\icat@copyrightlength]{2.71828in}{0in}}%
    \renewcommand{\thefootnote}{\arabic{footnote}}
}

\renewcommand{\footnoterule}{%
    \kern-3pt
    \hrule width 0.45\columnwidth
    \kern 2.6pt}

\newcommand{\icat@contactname}{}
\newcommand{\contactname}[1]{\renewcommand{\icat@contactname}{#1}}

\newcommand{\icat@contactaddress}{}
\newcommand{\contactaddress}[1]{\renewcommand{\icat@contactaddress}{#1}}

\newcommand{\icat@contactphone}{}
\newcommand{\contactphone}[1]{\renewcommand{\icat@contactphone}{#1}}

\newcommand{\icat@contactfax}{}
\newcommand{\contactfax}[1]{\renewcommand{\icat@contactfax}{#1}}

\newcommand{\icat@contactemail}{}
\newcommand{\contactemail}[1]{\renewcommand{\icat@contactemail}{#1}}

\newcommand{\icat@keywords}{}
\newcommand{\keywords}[1]{\renewcommand{\icat@keywords}{#1}}

\newcommand{\icat@estpages}{}
\newcommand{\estpages}[1]{\renewcommand{\icat@estpages}{#1}}

\newcommand{\icatopening}[1]{%
  \ClassError{icat}{%
    The icatopening command is no longer needed.\MessageBreak%
    Switch to the maketitle command and abstract environment}{}}
\InputIfFileExists{siggraph.cfg}
        {\typeout{***************************************^^J%
                  * Local config file siggraph.cfg used *^^J%
                  ***************************************}}
        {}
\endinput

% End of file 'icat.cls'.

